summaryrefslogtreecommitdiffstats
path: root/perl-install/modules.pm
diff options
context:
space:
mode:
authorOlivier Blin <oblin@mandriva.com>2007-08-21 14:46:48 +0000
committerOlivier Blin <oblin@mandriva.com>2007-08-21 14:46:48 +0000
commit50a4988ce2ef7000b220d2395dc6a45e5f478cfd (patch)
treec0c5d9cfd7f4bf4f3740da5bbbe7814925e22ca4 /perl-install/modules.pm
parent830a2579e35f1ba8b4963ae5d05cff46baf7142c (diff)
downloaddrakx-50a4988ce2ef7000b220d2395dc6a45e5f478cfd.tar
drakx-50a4988ce2ef7000b220d2395dc6a45e5f478cfd.tar.gz
drakx-50a4988ce2ef7000b220d2395dc6a45e5f478cfd.tar.bz2
drakx-50a4988ce2ef7000b220d2395dc6a45e5f478cfd.tar.xz
drakx-50a4988ce2ef7000b220d2395dc6a45e5f478cfd.zip
use usb_storage instead of usb-storage
Diffstat (limited to 'perl-install/modules.pm')
-rw-r--r--perl-install/modules.pm8
1 files changed, 4 insertions, 4 deletions
diff --git a/perl-install/modules.pm b/perl-install/modules.pm
index 96fb86203..01a88a18c 100644
--- a/perl-install/modules.pm
+++ b/perl-install/modules.pm
@@ -72,8 +72,8 @@ sub load_raw {
}
if (any { /^(mousedev|printer)$/ } @$l) {
sleep 2;
- } elsif (member('usb-storage', @$l)) {
- #- usb-storage is only modprobed when we know there is some scsi devices
+ } elsif (member('usb_storage', @$l)) {
+ #- usb_storage is only modprobed when we know there is some scsi devices
#- so trying hard to wait for devices to be detected
#- first sleep the minimum time usb-stor-scan takes
@@ -83,7 +83,7 @@ sub load_raw {
while ($retry++ < 10) {
fuzzy_pidofs('usb-stor-scan') or last;
sleep 1;
- log::l("waiting for usb-storage devices to appear (retry = $retry)");
+ log::l("waiting for usb_storage devices to appear (retry = $retry)");
}
}
}
@@ -135,7 +135,7 @@ sub load_category {
my @try_modules = (
if_($category =~ /scsi/,
- if_(detect_devices::usbStorage(), 'usb-storage'),
+ if_(detect_devices::usbStorage(), 'usb_storage'),
),
arch() =~ /ppc/ ? (
if_($category =~ /scsi/,